import javafx.animation.AnimationTimer;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.paint.Color;
import javafx.stage.Stage;
import javafx.scene.canvas.Canvas;
import javafx.scene.canvas.GraphicsContext;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.HBox;
import javafx.scene.control.Button;

public class AnimateSquare extends Application 
{
    private final Canvas canvas;
    private final GraphicsContext pen;    
    private final double SIZE = 50;
    private double xLoc;
    private double yLoc;
    private double xDir;
    private double yDir;
    public AnimateSquare()
    {
        canvas = new Canvas(500, 800);
        pen = canvas.getGraphicsContext2D();
        xLoc = canvas.getWidth()/2 + SIZE/2;
        yLoc = canvas.getHeight()/2 +  SIZE/2;
        xDir = 5;
        yDir = 5;
    }

    private void refresh()
    {
        pen.setFill(Color.WHITE);
        pen.fillRect(0, 0, canvas.getWidth(), canvas.getHeight());
        pen.setFill(Color.RED);
        pen.fillRect(xLoc - SIZE/2, yLoc - SIZE/2, SIZE, SIZE);
    }
    @Override
    public void start(final Stage primaryStage) 
    {
        BorderPane bp = new BorderPane();
        bp.setCenter(canvas);
        HBox hbox = new HBox();
        Button startButton = new Button("start");
        Button stopButton = new Button("stop");
        hbox.getChildren().addAll(startButton, stopButton);
        bp.setTop(hbox);
        primaryStage.setScene(new Scene(bp));
        primaryStage.show();
        refresh();
        AnimationTimer timer = new AnimationTimer() 
        {
            private long lastUpdate = 0;
            @Override
            public void handle(long now) 
            {
                
                if(now - lastUpdate > 2000000000 )
                {
                    now = lastUpdate;
                    final double width = canvas.getWidth();
                    final double height = canvas.getHeight();
                    if(xLoc <= SIZE/2 || xLoc >= width - SIZE/2)
                    {
                        xDir = -xDir;
                    }
                    if(yLoc <= SIZE/2 || yLoc >= height - SIZE/2)
                    {
                        yDir = -yDir;
                    }
                    xLoc += xDir;
                    yLoc += yDir;
                    refresh();
                }
            }
        };
        startButton.setOnAction(e -> timer.start());
        stopButton.setOnAction(e -> timer.stop());
    }
}
